Documentation
¶
Index ¶
- Constants
- Variables
- func AuditRules() map[string]*v1.AuditRule
- func RegisterMasterServiceHTTPServer(s *http.Server, srv MasterServiceHTTPServer)
- func RegisterMasterServiceServer(s grpc.ServiceRegistrar, srv MasterServiceServer)
- type MasterServiceClient
- type MasterServiceHTTPClient
- type MasterServiceHTTPClientImpl
- type MasterServiceHTTPServer
- type MasterServiceServer
- type UnimplementedMasterServiceServer
- type UnsafeMasterServiceServer
Constants ¶
const (
MasterService_Hello_FullMethodName = "/master.service.v1.MasterService/Hello"
)
const OperationMasterServiceHello = "/master.service.v1.MasterService/Hello"
Variables ¶
var File_master_service_v1_master_doc_proto protoreflect.FileDescriptor
var File_master_service_v1_master_proto protoreflect.FileDescriptor
var MasterService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "master.service.v1.MasterService", HandlerType: (*MasterServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Hello", Handler: _MasterService_Hello_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "master/service/v1/master.proto", }
MasterService_ServiceDesc is the grpc.ServiceDesc for MasterService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func AuditRules ¶ added in v0.5.0
AuditRules returns the audit rules for this package. Merge these with other packages' rules using audit.Middleware WithRulesFuncs.
func RegisterMasterServiceHTTPServer ¶
func RegisterMasterServiceHTTPServer(s *http.Server, srv MasterServiceHTTPServer)
func RegisterMasterServiceServer ¶
func RegisterMasterServiceServer(s grpc.ServiceRegistrar, srv MasterServiceServer)
Types ¶
type MasterServiceClient ¶
type MasterServiceClient interface {
Hello(ctx context.Context, in *v1.HelloRequest, opts ...grpc.CallOption) (*v1.HelloResponse, error)
}
MasterServiceClient is the client API for MasterService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewMasterServiceClient ¶
func NewMasterServiceClient(cc grpc.ClientConnInterface) MasterServiceClient
type MasterServiceHTTPClient ¶
type MasterServiceHTTPClient interface {
Hello(ctx context.Context, req *v1.HelloRequest, opts ...http.CallOption) (rsp *v1.HelloResponse, err error)
}
func NewMasterServiceHTTPClient ¶
func NewMasterServiceHTTPClient(client *http.Client) MasterServiceHTTPClient
type MasterServiceHTTPClientImpl ¶
type MasterServiceHTTPClientImpl struct {
// contains filtered or unexported fields
}
func (*MasterServiceHTTPClientImpl) Hello ¶
func (c *MasterServiceHTTPClientImpl) Hello(ctx context.Context, in *v1.HelloRequest, opts ...http.CallOption) (*v1.HelloResponse, error)
type MasterServiceHTTPServer ¶
type MasterServiceHTTPServer interface {
Hello(context.Context, *v1.HelloRequest) (*v1.HelloResponse, error)
}
type MasterServiceServer ¶
type MasterServiceServer interface {
Hello(context.Context, *v1.HelloRequest) (*v1.HelloResponse, error)
// contains filtered or unexported methods
}
MasterServiceServer is the server API for MasterService service. All implementations must embed UnimplementedMasterServiceServer for forward compatibility.
type UnimplementedMasterServiceServer ¶
type UnimplementedMasterServiceServer struct{}
UnimplementedMasterServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedMasterServiceServer) Hello ¶
func (UnimplementedMasterServiceServer) Hello(context.Context, *v1.HelloRequest) (*v1.HelloResponse, error)
type UnsafeMasterServiceServer ¶
type UnsafeMasterServiceServer interface {
// contains filtered or unexported methods
}
UnsafeMasterServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MasterServiceServer will result in compilation errors.